#!/usr/bin/env python
__usage__ = "setup.py command [--options]"
__description__ = "standard install script"
__author__ = "Reed Essick (reed.essick@ligo.org)"

#-------------------------------------------------

import os
import re

from setuptools import setup
import glob

#-------------------------------------------------

def find_version(path):
    """Extract the `__version__` string from the given file
    modified from the DQR setup.py, originally written by Duncan Macleod
    """
    with open(path, 'r') as fp:
        version_file = fp.read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")

#-------------------------------------------------

requires = [
    'confluent-kafka >= 0.11.5',
    'dqsegdb >= 1.4.0',
    'h5py >= 2.2.1',
    'matplotlib >= 1.2.0',
    'ligo-segments >= 1.0.0',
    'lscsoft-glue >= 1.59.2',
    'numpy >= 1.7.1',
    'scipy >= 0.12.1',
    'scikit-learn >= 0.18.2',
    'Jinja2 >= 2.1.0, != 2.9.0, != 2.9.1, < 2.10',
]

setup(
    name = 'iDQ',
    version=find_version(os.path.join('idq', '__init__.py')),
    url = 'https://git.ligo.org/reed.essick/iDQ',
    author = __author__,
    author_email = 'reed.essick@ligo.org',
    description = __description__,
    license = 'MIT',
    scripts = [
        'bin/idq-batch',            ### batch pipeline scripts
        'bin/idq-train',
        'bin/idq-calibrate',
        'bin/idq-evaluate',
        'bin/idq-timeseries',
        'bin/idq-condor_batch',     ### batch pipeline condor scripts
        'bin/idq-condor_train',
        'bin/idq-condor_evaluate',
        'bin/idq-condor_calibrate',
        'bin/idq-condor_timeseries',
        'bin/idq-stream',           ### streaming pipeline scripts
        'bin/idq-streaming_train',
        'bin/idq-streaming_evaluate',
        'bin/idq-streaming_calibrate',
        'bin/idq-streaming_timeseries',
        'bin/idq-report',           ### misc helper scripts
        'bin/idq-dqr',
        'bin/idq-monitor',
        'bin/idq-target-times',
        'bin/idq-check_config',
        'bin/idq-kwm2kws',
        'bin/idq-simtimeseries',    ### simulation scripts
    ],
    packages = [
        'idq',
        'idq.classifiers',
    ],
    data_files = [
        ('web/templates', glob.glob(os.path.join('etc/web/templates','*.html'))),
        ('etc', [
             'etc/idq.ini',
             'etc/mockclassifierdata.ini',
             'etc/Makefile.idq_install',
             'etc/kafka.properties',
             'etc/zookeeper.properties',
        ]),
    ],
    install_requires = [], # FIXME: should use 'requires', but they install unnecessary packages
)
